@@ -9,13 +9,14 @@ import pkg_resources
 
 from pytest_web_ui import runner
 from pytest_web_ui import result_tree
+from pytest_web_ui import environment
 
 LOGGER = logging.getLogger(__name__)
 
 
 def build_app(
-    directory: str, use_docker: bool,
-) -> Tuple[flask.Flask, flask_socketio.SocketIO, runner.EnvironmentManager]:
+    directory: str,
+) -> Tuple[flask.Flask, flask_socketio.SocketIO, runner.PyTestRunner]:
     """Build a Flask app to serve the API and static files."""
     build_dir = pkg_resources.resource_filename(__name__, "web_client/build")
     LOGGER.debug("build_dir: %s", build_dir)
@@ -25,7 +26,7 @@ def build_app(
     app = flask.Flask(__name__, root_path=build_dir, static_folder=static_dir)
     branch_schema = result_tree.BranchNodeSchema()
     socketio = flask_socketio.SocketIO(app)
-    test_runner = runner.PyTestRunner(directory, socketio, use_docker)
+    test_runner = runner.PyTestRunner(directory, socketio)
 
     @app.route("/")
     def index():
@@ -45,6 +46,16 @@ def build_app(
         LOGGER.info("Running test: %s", nodeid)
         test_runner.run_tests(nodeid)
 
+    @socketio.on("start env")
+    def start_env(nodeid):
+        LOGGER.info("starting env: %s", nodeid)
+        test_runner.start_env(nodeid)
+
+    @socketio.on("stop env")
+    def stop_env(nodeid):
+        LOGGER.info("stopping env: %s", nodeid)
+        test_runner.stop_env(nodeid)
+
     @socketio.on("connect")
     def connect():
         LOGGER.debug("Client connected")
@@ -53,4 +64,4 @@ def build_app(
     def disconnect():
         LOGGER.debug("Client disconnected")
 
-    return app, socketio, test_runner.environment
+    return app, socketio, test_runner
